import '@ui5/webcomponents/dist/CalendarLegend.js';
import type { CommonProps, Ui5DomRef } from '@ui5/webcomponents-react-base';
import type { ReactNode } from 'react';
interface CalendarLegendAttributes {
    /**
     * Hides the Non-Working day item in the legend.
     * @default false
     */
    hideNonWorkingDay?: boolean;
    /**
     * Hides the Selected day item in the legend.
     * @default false
     */
    hideSelectedDay?: boolean;
    /**
     * Hides the Today item in the legend.
     * @default false
     */
    hideToday?: boolean;
    /**
     * Hides the Working day item in the legend.
     * @default false
     */
    hideWorkingDay?: boolean;
}
interface CalendarLegendDomRef extends Required<CalendarLegendAttributes>, Ui5DomRef {
}
interface CalendarLegendPropTypes extends CalendarLegendAttributes, Omit<CommonProps, keyof CalendarLegendAttributes | 'children'> {
    /**
     * Defines the items of the component.
     */
    children?: ReactNode | ReactNode[];
}
/**
 * The `CalendarLegend` component is designed for use within the `Calendar` to display a legend.
 * Each `CalendarLegendItem` represents a unique date type, specifying its visual style
 * and a corresponding textual label.
 *
 *
 *
 * __Note__: This is a UI5 Web Component! [Repository](https://github.com/SAP/ui5-webcomponents) | [Documentation](https://sap.github.io/ui5-webcomponents/)
 *
 * @since [1.23.0](https://github.com/SAP/ui5-webcomponents/releases/tag/v1.23.0) of __@ui5/webcomponents__.
 */
declare const CalendarLegend: import("react").ForwardRefExoticComponent<CalendarLegendPropTypes & import("@ui5/webcomponents-react-base").WithWebComponentPropTypes & import("react").RefAttributes<CalendarLegendDomRef>>;
export { CalendarLegend };
export type { CalendarLegendDomRef, CalendarLegendPropTypes };
