import '@ui5/webcomponents/dist/TableHeaderRow.js';
import type { CommonProps, Ui5DomRef } from '@ui5/webcomponents-react-base';
import type { ReactNode } from 'react';
interface TableHeaderRowAttributes {
    /**
     * Sticks the `TableHeaderRow` to the top of a table.
     *
     * Note: If used in combination with overflowMode "Scroll", the table needs a defined height for the sticky header to work as expected.
     * @default false
     */
    sticky?: boolean;
}
interface TableHeaderRowDomRef extends Required<TableHeaderRowAttributes>, Ui5DomRef {
}
interface TableHeaderRowPropTypes extends TableHeaderRowAttributes, Omit<CommonProps, keyof TableHeaderRowAttributes | 'children'> {
    /**
     * Defines the cells of the component.
     *
     * **Note:** Use `TableHeaderCell` for the intended design.
     */
    children?: ReactNode | ReactNode[];
}
/**
 * The `TableHeaderRow` component represents the table headers of a `Table`.
 *
 * It is tightly coupled to the `Table` and should therefore be used in the `Table` only.
 * The header row is placed in the `headerRow` slot of the table.
 *
 *
 *
 * __Note__: This is a UI5 Web Component! [Repository](https://github.com/SAP/ui5-webcomponents) | [Documentation](https://sap.github.io/ui5-webcomponents/)
 *
 * @since [2.0.0](https://github.com/SAP/ui5-webcomponents/releases/tag/v2.0.0) of __@ui5/webcomponents__.
 */
declare const TableHeaderRow: import("react").ForwardRefExoticComponent<TableHeaderRowPropTypes & import("@ui5/webcomponents-react-base").WithWebComponentPropTypes & import("react").RefAttributes<TableHeaderRowDomRef>>;
export { TableHeaderRow };
export type { TableHeaderRowDomRef, TableHeaderRowPropTypes };
