import type TitleLevel from '@ui5/webcomponents/dist/types/TitleLevel.js';
import type { ReactNode } from 'react';
import type { CommonProps } from '../../types/index.js';
export interface ObjectPageSectionPropTypes extends CommonProps {
    /**
     * Defines the ID of the `ObjectPageSection`.
     *
     * __Note:__ The `id` is taken into account when the section selection changes.
     */
    id: string;
    /**
     * Defines the content of the `ObjectPageSection`.
     *
     * __Note:__ Only use subsections if more than one is available. Otherwise, add the content of the section directly as `child`.
     */
    children: ReactNode | ReactNode[];
    /**
     * Defines the title of the `ObjectPageSection`.
     *
     */
    titleText: string;
    /**
     * Defines whether the title is always displayed in uppercase.
     *
     */
    titleTextUppercase?: boolean;
    /**
     * Determines whether to display the Section title or not.
     */
    hideTitleText?: boolean;
    /**
     * Determines the ARIA level of the ObjectPageSection `titleText`. The ARIA level is used by assisting technologies, such as screen readers, to create a hierarchical site map for faster navigation.
     *
     * __Note:__ Defining a `titleTextLevel` will add aria-level attribute from 1 to 6, instead of changing the ObjectPageSectionBase title HTML tag from H1 to H6.
     * For example: if titleTextLevel is TitleLevel.H1, it will result as aria-level of 1 added to the ObjectPageSection title.
     *
     * @default TitleLevel.H3
     */
    titleTextLevel?: TitleLevel | keyof typeof TitleLevel;
    /**
     * Determines whether the Section title wraps on multiple lines, when the available space is not enough.
     */
    wrapTitleText?: boolean;
    /**
     * Section header content.
     *
     * __Note__: Although this prop accepts all HTML Elements, it is strongly recommended that you only use non-focusable elements to preserve the intended design.
     */
    header?: ReactNode;
}
/**
 * Top-level information container of an `ObjectPage`.
 */
declare const ObjectPageSection: import("react").ForwardRefExoticComponent<ObjectPageSectionPropTypes & import("react").RefAttributes<HTMLElement>>;
export { ObjectPageSection };
