import '@ui5/webcomponents/dist/ToolbarSeparator.js';
import type ToolbarItemOverflowBehavior from '@ui5/webcomponents/dist/types/ToolbarItemOverflowBehavior.js';
import type { CommonProps, Ui5DomRef } from '@ui5/webcomponents-react-base';
interface ToolbarSeparatorAttributes {
    /**
     * Property used to define the access of the item to the overflow Popover. If "NeverOverflow" option is set,
     * the item never goes in the Popover, if "AlwaysOverflow" - it never comes out of it.
     * @default "Default"
     */
    overflowPriority?: ToolbarItemOverflowBehavior | keyof typeof ToolbarItemOverflowBehavior;
    /**
     * Defines if the toolbar overflow popup should close upon intereaction with the item.
     * It will close by default.
     * @default false
     */
    preventOverflowClosing?: boolean;
}
interface ToolbarSeparatorDomRef extends Required<ToolbarSeparatorAttributes>, Ui5DomRef {
}
interface ToolbarSeparatorPropTypes extends ToolbarSeparatorAttributes, Omit<CommonProps, keyof ToolbarSeparatorAttributes> {
}
/**
 * The `ToolbarSeparator` is an element, used for visual separation between two elements.
 * It takes no space in calculating toolbar items width.
 *
 * __Note__: This is a UI5 Web Component! [Repository](https://github.com/SAP/ui5-webcomponents) | [Documentation](https://sap.github.io/ui5-webcomponents/)
 *
 * @since [1.17.0](https://github.com/SAP/ui5-webcomponents/releases/tag/v1.17.0) of __@ui5/webcomponents__.
 * @abstract
 */
declare const ToolbarSeparator: import("react").ForwardRefExoticComponent<ToolbarSeparatorPropTypes & import("@ui5/webcomponents-react-base").WithWebComponentPropTypes & import("react").RefAttributes<ToolbarSeparatorDomRef>>;
export { ToolbarSeparator };
export type { ToolbarSeparatorDomRef, ToolbarSeparatorPropTypes };
